@@ -22,25 +22,35 @@ from cliff import show
 
 from mistralclient.api.v2 import executions
 from mistralclient.commands.v2 import base
+from mistralclient import utils
 
 LOG = logging.getLogger(__name__)
 
 
-def format(execution=None):
+def format_list(execution=None):
+    return format(execution, lister=True)
+
+
+def format(execution=None, lister=False):
     columns = (
         'ID',
         'Workflow',
         'State',
+        'State info',
         'Created at',
         'Updated at'
     )
     # TODO(nmakhotkin) Add parent task id when it's implemented in API.
 
     if execution:
+        state_info = (execution.state_info if not lister
+                      else base.cut(execution.state_info))
+
         data = (
             execution.id,
             execution.workflow_name,
             execution.state,
+            state_info,
             execution.created_at,
             execution.updated_at or '<none>'
         )
@@ -54,7 +64,7 @@ class List(base.MistralLister):
     """List all executions."""
 
     def _get_format_function(self):
-        return format
+        return format_list
 
     def _get_resources(self, parsed_args):
         return executions.ExecutionManager(self.app.client).list()
@@ -71,8 +81,8 @@ class Get(show.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        execution = executions.ExecutionManager(self.app.client)\
-            .get(parsed_args.id)
+        execution = executions.ExecutionManager(self.app.client).get(
+            parsed_args.id)
 
         return format(execution)
 
@@ -85,7 +95,7 @@ class Create(show.ShowOne):
 
         parser.add_argument(
             'workflow_name',
-            help='Execution workflow'
+            help='Workflow name'
         )
         parser.add_argument(
             'workflow_input',
@@ -117,10 +127,10 @@ class Create(show.ShowOne):
         else:
             params = {}
 
-        execution = executions.ExecutionManager(self.app.client)\
-            .create(parsed_args.workflow_name,
-                    wf_input,
-                    **params)
+        execution = executions.ExecutionManager(self.app.client).create(
+            parsed_args.workflow_name,
+            wf_input,
+            **params)
 
         return format(execution)
 
@@ -131,12 +141,22 @@ class Delete(command.Command):
     def get_parser(self, prog_name):
         parser = super(Delete, self).get_parser(prog_name)
 
-        parser.add_argument('id', help='Execution identifier')
+        parser.add_argument(
+            'id',
+            nargs='+',
+            help='Id of execution identifier(s).'
+        )
 
         return parser
 
     def take_action(self, parsed_args):
-        executions.ExecutionManager(self.app.client).delete(parsed_args.id)
+        exe_mgr = executions.ExecutionManager(self.app.client)
+        utils.do_action_on_many(
+            lambda s: exe_mgr.delete(s),
+            parsed_args.id,
+            "Request to delete execution %s has been accepted.",
+            "Unable to delete the specified execution(s)."
+        )
 
 
 class Update(show.ShowOne):
@@ -158,9 +178,9 @@ class Update(show.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        execution = executions.ExecutionManager(self.app.client)\
-            .update(parsed_args.id,
-                    parsed_args.state)
+        execution = executions.ExecutionManager(self.app.client).update(
+            parsed_args.id,
+            parsed_args.state)
 
         return format(execution)
 
@@ -176,8 +196,8 @@ class GetInput(command.Command):
         return parser
 
     def take_action(self, parsed_args):
-        ex_input = executions.ExecutionManager(self.app.client)\
-            .get(parsed_args.id).input
+        ex_input = executions.ExecutionManager(self.app.client).get(
+            parsed_args.id).input
 
         try:
             ex_input = json.loads(ex_input)
@@ -199,8 +219,8 @@ class GetOutput(command.Command):
         return parser
 
     def take_action(self, parsed_args):
-        output = executions.ExecutionManager(self.app.client)\
-            .get(parsed_args.id).output
+        output = executions.ExecutionManager(self.app.client).get(
+            parsed_args.id).output
 
         try:
             output = json.loads(output)
